FieldKey<T> class

A Key for customizing FormxState.toMap & other outputs.

Inheritance
Available extensions

Constructors

FieldKey(String key, {bool? keepMask, Unmasker? unmasker, FieldAdapter<T>? adapter})
Creates a FieldKey with a key.

Properties

adapter FieldAdapter<T>?
The adapter function to convert the T to any value.
final
currentContext BuildContext?
The build context in which the widget with this key builds.
no setterinherited
currentState FormFieldState<T>?
The State for the widget in the tree that currently has this global key.
no setterinherited
currentWidget Widget?
The widget in the tree that currently has this global key.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
keepMask bool?
Whether to unmask the value. Overrides FormxOptions.keepMask.
final
key String
The FormField.key value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state FormFieldState

Available on GlobalKey<FormFieldState>, provided by the FormxFormFieldKeyExtension extension

Requires the FormxFieldState of this FormFieldState.
no setter
unmasker Unmasker?
The unmasker function to unmask the value.
final
value String?

Available on Key, provided by the FormFieldKeyExtension extension

Attempts to get the value of this Key if it is an String.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
options([FormxOptions? options]) FormxOptions
Resolves the FormxOptions for this FieldKey.
options<T>({bool? keepMask, Unmasker? unmasker, FieldAdapter<T>? adapter}) FieldKey<T>

Available on Key, provided by the FormFieldKeyExtension extension

Creates a FieldKey of type T of this Key.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited