FormxFieldState<T> class

The state of a FormxField.

Inheritance
Available extensions

Constructors

FormxFieldState()

Properties

bucket RestorationBucket?
The RestorationBucket used for the restoration data of the RestorablePropertys registered to this mixin.
no setterinherited
context BuildContext
The location in the tree where this widget builds.
no setterinherited
date DateTime?

Available on FormFieldState<T>, provided by the FormFieldStateExtension extension

Returns the FormFieldState.value as a DateTime.
no setter
debugText String

Available on FormFieldState<T>, provided by the FormFieldStateMaybe extension

no setter
errorText String?
The current validation error returned by the FormField.validator callback, or the manually provided error message using the FormField.forceErrorText property.
no setteroverride
extraKey GlobalKey<FormFieldState>?
getter/setter pair
fieldKey FieldKey<T>?

Available on FormFieldState<T>, provided by the FormFieldStateExtension extension

The options of this FormField.
no setter
hasError bool
True if this field has any validation errors.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasInteractedByUser bool
Returns true if the user has modified the value of this field.
no setterinherited
isEmpty bool?

Available on FormFieldState<T>, provided by the FormFieldStateExtension extension

Whether value is empty.
no setter
isInitial bool

Available on FormFieldState<T>, provided by the FormFieldStateExtension extension

Whether FormFieldState.value is the same as FormField.initialValue.
no setter
isValid bool
True if the current value is valid.
no setteroverride
key String?

Available on FormFieldState<T>, provided by the FormFieldStateExtension extension

The Key value of this FormFieldState.
no setter
mounted bool
Whether this State object is currently in a tree.
no setterinherited
number num?

Available on FormFieldState<T>, provided by the FormFieldStateExtension extension

Returns the FormFieldState.value as a num.
no setter
onChanged ↔ void Function(T? value)?
getter/setter pair
onReset ↔ void Function()?
getter/setter pair
restorationId String?
The restoration ID used for the RestorationBucket in which the mixin will store the restoration data of all registered properties.
no setterinherited
restorePending bool
Whether restoreState will be called at the beginning of the next build phase.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String

Available on FormFieldState<T>, provided by the FormFieldStateExtension extension

Returns the FormFieldState.value as a String.
no setter
time TimeOfDay?

Available on FormFieldState<T>, provided by the FormFieldStateExtension extension

Returns the FormFieldState.value as a DateTime.
no setter
value → T?
The current value of the form field.
no setterinherited
widget FormxField<T>
The current configuration.
no setteroverride

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
clear() → void

Available on FormFieldState<T>, provided by the FormFieldStateExtension extension

deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChange(T? value) → void
Updates this field's state to the new value. Useful for responding to child widget changes, e.g. Slider's Slider.onChanged argument.
override
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didToggleBucket(RestorationBucket? oldBucket) → void
Called when bucket switches between null and non-null values.
inherited
didUpdateRestorationId() → void
Must be called when the value returned by restorationId changes.
inherited
didUpdateWidget(covariant FormField<T> oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
getOptions([FormxOptions? options]) FormxOptions

Available on FormFieldState, provided by the FormFieldOptionsExtension extension

Resolves the FormxOptions for this FormFieldState.
initState() → void
Called when this object is inserted into the tree.
inherited
maybeChange(Object? value) → void

Available on FormFieldState<T>, provided by the FormFieldStateMaybe extension

Atempts to change the FormFieldState.value if value is of type T.
maybeFormat(Object? value, [bool format = true]) Object?

Available on FormFieldState<T>, provided by the FormFieldStateMaybe extension

Atempts to format the value with TextField.inputFormatters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
registerForRestoration(RestorableProperty<Object?> property, String restorationId) → void
Registers a RestorableProperty for state restoration.
inherited
reset() → void
Resets the field to its initial value.
override
restoreState(RestorationBucket? oldBucket, bool initialRestore) → void
Called to initialize or restore the RestorablePropertys used by the State object.
inherited
save() → void
Calls the FormField's onSaved method with the current value.
override
setErrorText(String? errorText) → void

Available on FormFieldState<T>, provided by the ValidatorSetError extension

Sets the errorText of this FormFieldState.
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setValue(T? value) → void
Sets the value associated with this form field.
inherited
submit({FormxOptions? options, String? errorMessage}) Object?

Available on FormFieldState<T>, provided by the FormFieldStateExtension extension

Performs validate, save, and returns toValue with options. Throws a FormxException if field is invalid.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
toValue({FormxOptions? options}) Object?

Available on FormFieldState<T>, provided by the FormFieldStateExtension extension

Returns the FormFieldState.value modified by form/field options.
trySubmit({FormxOptions? options}) Object?

Available on FormFieldState<T>, provided by the FormFieldStateExtension extension

Performs validate, save, and returns toValue with options. Returns null if field is invalid.
unregisterFromRestoration(RestorableProperty<Object?> property) → void
Unregisters a RestorableProperty from state restoration.
inherited
validate() bool
Calls FormField.validator to set the errorText only if FormField.forceErrorText is null. When FormField.forceErrorText is not null, FormField.validator will not be called.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited