FormxMapExtension<K, V> extension

A map extension that removes all null or empty values.

on

Methods

castJson() Map<String, dynamic>

Available on Map<K, V>, provided by the FormxMapExtension extension

Returns a new Map casted as Map<String, dynamic>.
clean({bool nonNulls = true, bool nonEmptyMaps = true, bool nonEmptyStrings = true, bool nonEmptyIterables = false}) → void

Available on Map<K, V>, provided by the FormxMapExtension extension

Removes all null or empty values from this Map and nesteds.
cleaned({bool nonNulls = true, bool nonEmptyMaps = true, bool nonEmptyStrings = true, bool nonEmptyIterables = false}) Map<K, V>

Available on Map<K, V>, provided by the FormxMapExtension extension

Returns a new Map with all null or empty values removed.
keysWhere(bool test(K key, V value)) List<K>

Available on Map<K, V>, provided by the FormxMapExtension extension

Returns a new List with only the keys that satisfy test.
valuesWhere(bool test(K key, V value)) List<V>

Available on Map<K, V>, provided by the FormxMapExtension extension

Returns a new List with only the values that satisfy test.