FormxOptions class

Global options for all FormxState methods.

Constructors

FormxOptions({bool keepMask = false, bool nonNulls = true, bool nonEmptyMaps = true, bool nonEmptyStrings = true, bool nonEmptyIterables = false, Unmasker unmasker = defaultUnmasker, FieldAdapter<Object> adapter = defaultAdapter})
Creates a new FormxOptions instance.
const
FormxOptions.none({bool keepMask = true, bool nonNulls = false, bool nonEmptyMaps = false, bool nonEmptyStrings = false, bool nonEmptyIterables = false, Unmasker unmasker = defaultUnmasker, FieldAdapter<Object> adapter = defaultAdapter})
Creates a new FormxOptions instance with all options disabled.
const

Properties

adapter FieldAdapter<Object>
Global adapter for any value.
final
hashCode int
The hash code for this object.
no setterinherited
keepMask bool
Whether to unmask all masked text fields.
final
nonEmptyIterables bool
Whether to remove all empty iterables.
final
nonEmptyMaps bool
Whether to remove all empty maps.
final
nonEmptyStrings bool
Whether to remove all empty strings.
final
nonNulls bool
Whether to remove all null values.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unmasker Unmasker
Global unmasker for unmasking TextInputFormatter values.
final

Methods

copyWith({bool? keepMask, bool? nonNulls, bool? nonEmptyMaps, bool? nonEmptyStrings, bool? nonEmptyIterables, FieldAdapter<Object>? adapter, Unmasker? unmasker}) FormxOptions
Creates a copy of this FormxOptions with the provided values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaultAdapter(Object value) → dynamic
The default JSON-serializable adapter for any value.
defaultDateAdapter(DateTime date) → dynamic
The default JSON-serializable format for DateTime.
defaultEnumAdapter(Enum type) → dynamic
The default JSON-serializable format for Enum.
defaultUnmasker(String value, TextInputFormatter formatter) String?
The default unmasker for TextInputFormatter.