FormxMapExtension<K, V> extension
A map extension that removes all null or empty values.
- on
-
- Map<
K, V>
- Map<
Methods
-
castJson(
) → Map< String, dynamic> -
Available on Map<
Returns a new Map casted asK, V> , provided by the FormxMapExtension extensionMap<String, dynamic>. -
clean(
{bool nonNulls = true, bool nonEmptyMaps = true, bool nonEmptyStrings = true, bool nonEmptyIterables = false}) → void -
Available on Map<
Removes all null or empty values from this Map and nesteds.K, V> , provided by the FormxMapExtension extension -
cleaned(
{bool nonNulls = true, bool nonEmptyMaps = true, bool nonEmptyStrings = true, bool nonEmptyIterables = false}) → Map< K, V> -
Available on Map<
Returns a new Map with all null or empty values removed.K, V> , provided by the FormxMapExtension extension -
keysWhere(
bool test(K key, V value)) → List< K> -
Available on Map<
Returns a new List with only the keys that satisfyK, V> , provided by the FormxMapExtension extensiontest. -
valuesWhere(
bool test(K key, V value)) → List< V> -
Available on Map<
Returns a new List with only the values that satisfyK, V> , provided by the FormxMapExtension extensiontest.